
errors = {
    "421-connection-timeout":                                   "421 Connection timeout",
    "421-excessive-amounts-of-data":                            "421 Excessive amounts of data sent to server.",
    "451-please-try-again-later":                               "451 Please try again later.",
    "500-line-too-long":                                        "500 Line too long",
    "501-ehlo-invalid-domain-address":                          "501 EHLO Invalid domain address.",
    "502-turn-disallowed":                                      "502 TURN disallowed",
    "502-unimplemented-command":                                "502 Unimplemented command",
    "502-use-helo-ehlo-first":                                  "502 Use HELO/EHLO first",
    "502-vrfy-disallowed":                                      "502 VRFY disallowed",
    "503-issue-reset-to-start-over":                            "503 Issue a reset if you want to start over",
    "503-must-have-sender-and-recipient-first":                 "503 Must have sender and recipient first.",
    "503-must-have-sender-first":                               "503 Must have sender first.",
    "504-authentication-type-not-specified":                    "504 Authentication type not specified.",
    "530-smtp-authentication-is-required":                      "530 SMTP authentication is required.",
    "535-authentication-failed-restarting":                     "535 Authentication failed. Restarting authentication process.",
    "550-a-valid-address-is-required":                          "550 A valid address is required",
    "550-account-is-not-active":                                "550 Account is not active.",
    "550-alias-is-not-active":                                  "550 Alias is not active.",
    "550-blocked-by-spf":                                       "550 Blocked by SPF",
    "550-delivery-is-not-allowed-to-this-address":              "550 Delivery is not allowed to this address",
    "550-distribution-list-is-not-active":                      "550 Distribution list is not active.",
    "550-domain-has-been-disabled":                             "550 Domain has been disabled.",
    "550-invalid-syntax":                                       "550 Invalid syntax. Syntax should be MAIL FROM:<userdomain>[crlf]",
    "550-login-credentials-no-longer-valid":                    "550 Login credentials no longer valid. Please re-authenticate.",
    "550-mail-server-configuration-error":                      "550 Mail server configuration error. Too many recursive forwards.",
    "550-not-authorized":                                       "550 Not authorized.",
    "550-recipient-not-in-route-list":                          "550 Recipient not in route list.",
    "550-sender-address-must-be-specified":                     "550 Sender address must be specified.",
    "550-sender-domain-does-not-have-any-mx-records":           "550 Sender domain does not have any MX records.",
    "550-the-address-is-not-valid":                             "550 The address is not valid.",
    "550-the-host-name-specified-in-helo-does-not-match-ip":    "550 The host name specified in HELO does not match IP address.",
    "550-unknown-user":                                         "550 Unknown user",
    "550-other-error-message":                                  "550 <Other error message>",
    "552-message-size-exceeds-fixed-maximum":                   "552 Message size exceeds fixed maximum message size. Size: x KB, Max size: y KB",
    "554-rejected":                                             "554 Rejected",
    "554-your-message-was-received-but-could-not-be-saved":     "554 Your message was received but it could not be saved. Please retry later.",
    "554-rejected-containing-bare-lfs":                         "554 Rejected - Message containing bare LF's.",
    "554-rejected-no-data-saved":                               "554 Rejected - No data saved.",
    "554-rejected-other":                                       "554 Rejected - <other error message>",
    "554-tagged-as-spam-by-spamassassin":                       "554 Tagged as Spam by SpamAssassin",
    "550-mailbox-unavailable":                                  "550 Mailbox unavailable",
    "550-sender-verification-failed":                           "550 Sender verification failed",
}
